@@ -14,17 +14,17 @@ __status__		= "production"
 #
 #
 #	Copyright (c) Sander Granneman 2019
-#	
+#
 #	Permission is hereby granted, free of charge, to any person obtaining a copy
 #	of this software and associated documentation files (the "Software"), to deal
 #	in the Software without restriction, including without limitation the rights
 #	to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 #	copies of the Software, and to permit persons to whom the Software is
 #	furnished to do so, subject to the following conditions:
-#	
+#
 #	The above copyright notice and this permission notice shall be included in
 #	all copies or substantial portions of the Software.
-#	
+#
 #	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 #	IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 #	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
@@ -84,7 +84,7 @@ class PyCounters(ParseAlignmentFile,ParseCountersOutput):
 					if chromosome not in list_of_tuples:
 						list_of_tuples[chromosome] = self.gtf.chromosomeGeneCoordIterator(chromosome,numpy=True,sequence=sequence)
 					if len(list_of_tuples[chromosome]) > 0:
-						search_results = numpy_overlap(list_of_tuples[chromosome],read_start,read_end-1,overlap=min_overlap)
+						search_results = numpy_overlap(list_of_tuples[chromosome],read_start,read_end,overlap=min_overlap)
 					else:
 						continue
 				except AssertionError:			# in case you want to run pyReadCounters with a smaller GTF. This should ignore any errors
@@ -133,7 +133,7 @@ class PyCounters(ParseAlignmentFile,ParseCountersOutput):
 					if chromosome not in list_of_tuples:
 						list_of_tuples[chromosome] = self.gtf.chromosomeGeneCoordIterator(chromosome,numpy=True,sequence=sequence)
 					if len(list_of_tuples[chromosome]) > 0:
-						search_results = numpy_overlap(list_of_tuples[chromosome],read_start,read_end-1,overlap=min_overlap,returnall=True)
+						search_results = numpy_overlap(list_of_tuples[chromosome],read_start,read_end,overlap=min_overlap,returnall=True)
 					else:
 						continue
 				except AssertionError:			# in case you want to run pyReadCounters with a smaller GTF. This should ignore any errors
@@ -195,7 +195,7 @@ class PyCounters(ParseAlignmentFile,ParseCountersOutput):
 		if rpkm:
 			file_out.write("# feature\tsense_overlap\tsense-RPKM\tanti-sense_overlap\tanti-sense-RPKM\tcDNA count\n")
 		else:
-			file_out.write("# feature\tsense_overlap\tanti-sense_overlap\tcDNA count\n")		 
+			file_out.write("# feature\tsense_overlap\tanti-sense_overlap\tcDNA count\n")
 		for annotation,count in sorted(list(self.annotations_count.items()), key=lambda k_v: k_v[1],reverse=True):
 			total_sense,total_anti_sense = [sum(i) for i in zip(*iter(self.datadictionary[annotation].values()))]
 			if rpkm:
