@@ -290,7 +290,7 @@ class FindMotifs():
 						list_of_tuples[chromosome] = self.__gtf.chromosomeGeneCoordIterator(chromosome,numpy=True)
 					except AssertionError:
 						continue
-				genes = numpy_overlap(list_of_tuples[chromosome],motif_start,motif_end-1,overlap=1)
+				genes = numpy_overlap(list_of_tuples[chromosome],motif_start,motif_end,overlap=1)
 				if genes:
 					gene_name = ",".join(genes)
 					gene_id = ",".join([self.__gtf.gene2orf(gene) for gene in genes])
